<?php
/**
 * Latest Theme Customizer
 *
 * @package Latest
 */

/**
 * @param WP_Customize_Manager $wp_customize Theme Customizer object
 */
function latest_customize_register( $wp_customize ) {

	$wp_customize->add_section(
		'theme_options',
		array(
			'title'		=> esc_html__( 'Theme Options', 'latest' ),
			'priority'	=> 6,
		)
	);

	$wp_customize->add_setting(
		'masonry_off',
		array(
			'default'			=> 0,
			'sanitize_callback'	=> 'absint'
		)
	);
	$wp_customize->add_control(
			'masonry_off',
			array(
				'settings'	=> 'masonry_off',
				'section'	=> 'theme_options',
				'label'		=> esc_html__( 'Disable Masonry Grid Layout', 'latest' ),
				'type'		=> 'checkbox',
			)
	);

	$wp_customize->add_setting(
		'masonry_columns',
		array(
			'default'			=> '3',
			'sanitize_callback'	=> 'latest_sanitize_choices',
		)
	);
	$wp_customize->add_control(
		'masonry_columns',
		array(
			'label'		=> esc_html__( 'Masonry Columns', 'latest' ),
			'type'		=> 'select',
			'section'	=> 'theme_options',
			'choices'	=> array(
				'2'	=> esc_html__( '2', 'latest' ),
				'3'	=> esc_html__( '3', 'latest' ),
				'4'	=> esc_html__( '4', 'latest' ),
				'5'	=> esc_html__( '5', 'latest' ),
				'6'	=> esc_html__( '6', 'latest' ),
			),
		)
	);

	$wp_customize->add_setting(
		'sidebar_position',
		array(
			'default'			=> 'right',
			'sanitize_callback'	=> 'latest_sanitize_choices',
		)
	);
	$wp_customize->add_control(
		'sidebar_position',
		array(
			'label'		=> esc_html__( 'Sidebar Position', 'latest' ),
			'type'		=> 'select',
			'section'	=> 'theme_options',
			'choices'	=> array(
				'left'	=> esc_html__( 'Left', 'latest' ),
				'right'	=> esc_html__( 'Right', 'latest' ),
			),
		)
	);

}
add_action('customize_register', 'latest_customize_register');


/**
 * Sanitization functions
 */

function latest_sanitize_choices( $input, $setting ) {
    global $wp_customize;
 
    $control = $wp_customize->get_control( $setting->id );
 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}
